#include <stdio.h>
#include <assert.h>
#include <math.h>
#include <algorithm>
#include <limits>
#include <string.h>

const int SIZE = 1<<10;

template<class Item, int Size> class Array {
	Item arr[Size];
public:
	inline Item &operator[](int i) { return arr[i]; }
	inline const Item &operator[](int i) const { return arr[i]; }
};

const int DIM = 5;
const double TINY = 1e-9;
const double INFTY = std::numeric_limits<double>::infinity();

typedef Array<double, DIM> Vector;
typedef Array<Vector, SIZE> Matrix;

Matrix matr[DIM+1];
Vector goal[DIM+1];

//#define DEBUG
#define MASK "%8.5lf"

#ifdef DEBUG
void PrintEliminated(int d, int elim) {
	for (int t = 0; t < 5-d; t++) printf("    ");
	printf("Eliminate from %d {", elim);
	printf("\n");
}
void PrintSolution(int d, const Vector &sol, double gfVal) {
	for (int t = 0; t < 5-d; t++) printf("    ");
	printf("} got solution ");
	for (int j = 0; j < d; j++) printf(" " MASK, sol[j]);
	printf("  =>>  " MASK, gfVal);
	printf("\n");
}
void PrintProblem(int n, int d) {
	for (int t = 0; t < 5-d; t++) printf("    ");
	printf("Minimize: ");
	for (int j = 0; j < d; j++) printf(" " MASK, goal[d][j]);
	printf("\n");

	for (int i = 0; i < n; i++) {
		for (int t = 0; t < 5-d; t++) printf("    ");
		printf("inequ <=: ");
		for (int j = 0; j < d; j++) printf(" " MASK, matr[d][i][j]);
		printf("\n");
	}

	fflush(stdout);
}
#else
void PrintEliminated(int d, int elim) {}
void PrintSolution(int d, const Vector &sol, double gfVal) {}
void PrintProblem(int n, int d) {}
#endif


double GoalFunction(int d, const Vector &G, const Vector &sol) {
	double res = 0.0;
	double norm = 0.0;
	for (int i = 0; i<d; i++) {
		res += G[i] * sol[i];
		norm += sol[i] * sol[i];
	}
	norm = sqrt(norm);
	if (norm < TINY) return INFTY;
	return res / norm;
}

bool Solve(int n, int d, Vector &sol) {
	const Matrix &M = matr[d];
	const Vector &G = goal[d];
	PrintProblem(n, d);

	//optimal solution without any constraints
	for (int j = 0; j<d; j++)
		sol[j] = -G[j];
	double gf = GoalFunction(d, G, sol);
	if (gf == INFTY) return false;
		
	//iterate over constraints
	for (int i = 0; i < n; i++) {
		//check constraint
		double res = 0.0;
		for (int j = 0; j < d; j++)
			res += M[i][j] * sol[j];

		if (res <= TINY) continue;

		//not necessary: after elimination goal function in recursive call will surely be zero
//		if (d == 1) return false;

		//find pivot element in the constraint row
		Vector alpha = M[i];
		int sub = -1;
		double maxCoeff = TINY;
		for (int j = 0; j < d; j++) {
			double t = fabs(alpha[j]);
			if (maxCoeff < t) {
				maxCoeff = t;
				sub = j;
			}
		}
		assert(sub >= 0);

		Vector rcos, rsin;
		//rotate all elements in constraint row to the pivot one
		for (int j = 0; j<d; j++) if (j != sub) {
			double &a = alpha[sub];
			double &b = alpha[j];
			double r = hypot(a, b);
			double c = a / r, s = b / r;
			a = r;  b = 0;
			rcos[j] = c;
			rsin[j] = s;
		}

		//create a new problem with orthogonal change of variables
		Matrix &nM = matr[d-1];
		Vector &nG = goal[d-1];
		//write matrix + goal
		for (int u = -1; u < i; u++) {
			Vector row = (u<0 ? G : M[u]);
			Vector &dst = (u<0 ? nG : nM[u]);

			//rotate
			for (int j = 0; j < d; j++) if (j != sub) {
				double &a = row[sub];
				double &b = row[j];
				double c = rcos[j], s = rsin[j];
				double na =  c * a + s * b;
				double nb = -s * a + c * b;
				a = na;  b = nb;
			}

			//eliminate (relabel)
			int jj = 0;
			for (int j = 0; j < d; j++) if (j != sub)
				dst[jj++] = row[j];
			assert(jj == d-1);
		}

		PrintEliminated(d, i);

		//recursively solve the substituted problem
		Vector rsol;
		bool slv = Solve(i, d-1, rsol);
		if (!slv) return false;

		//obtain the solution:
		//back relabel
		for (int j = 0; j<d; j++)
            sol[j] = (j==sub ? 0.0 : rsol[j - (j>sub)]);
		//back rotate
		for (int j = d-1; j>=0; j--) if (j != sub) {
			double &a = sol[sub];
			double &b = sol[j];
			double c = rcos[j], s = -rsin[j];
			double na =  c * a + s * b;
			double nb = -s * a + c * b;
			a = na;  b = nb;
		}

		gf = GoalFunction(d, G, sol);

		PrintSolution(d, sol, gf);
	}

	return true;
}

int n;
Array<Array<double, DIM>, SIZE> pts;

int main() {
	freopen("input.txt", "r", stdin);
	freopen("output.txt", "w", stdout);

	for (int i = 0; i < 5; i++)
		for (int j = 0; j < 4; j++)
			scanf("%lf", &pts[i][j]);
	int h = 5;

	scanf("%d", &n);
	for (int i = 0; i < n; i++) {
		for (int j = 0; j < 4; j++)
			scanf("%lf", &pts[h][j]);

		std::random_shuffle(&pts[0], &pts[h]);
		
		memset(&goal, 0, sizeof(goal));
		for (int d = 0; d<5; d++)
			memset(&matr[d], 0, (h+10) * sizeof(matr[d][0]));

		for (int u = 0; u < h; u++) {
			for (int j = 0; j < 4; j++)
				matr[5][u][j] = pts[u][j] - pts[h][j];
			matr[5][u][4] = 1.0;
			goal[5][4] = -1.0;
		}
		
		Vector sol;
		bool slv = Solve(h, 5, sol);

		if (slv && sol[4] >= 0.0) {
    		double dist = 1e+50;
		    for (int u = 0; u < h; u++) {
    			double tdst = 0.0;
			    double tnorm = 0.0;
			    for (int j = 0; j < 4; j++) {
    				tdst += (pts[h][j] - pts[u][j]) * sol[j];
				    tnorm += sol[j] * sol[j];
			    }
			    assert(tnorm > TINY);
			    tdst /= sqrt(tnorm);
			    if (dist > tdst)
    				dist = tdst;
		    }
//		    fprintf(stderr, "Distance = %0.15lf\n", dist);
            assert(dist > 0.002);

			printf("Rebuild\n");
			h++;
        }
        else {
//		    fprintf(stderr, "Problem not solved\n");

			printf("Ignore\n");
        }

	}
	
}
