#include <iostream>
#include <cstdio>
#include <cmath>
#include <cassert>

using namespace std;

const double epsilon = 1e-9;

bool doubleEqual (const double a, const double b)
{
    return abs (a - b) < epsilon;
}

bool doubleLessOrEqual (const double a, const double b)
{
    return doubleEqual (a, b) || a < b;
}

bool doubleLess (const double a, const double b)
{
    return a < b && !doubleEqual(a, b);
}

double sqr(double x) { return x*x; }

struct point
{
    double x;
    double y;

    point(double a_x = 0, double a_y = 0)
    {
        x = a_x;
        y = a_y;
    }

    bool operator== (const point& other) const
    {
        return doubleEqual(x, other.x) && doubleEqual(y, other.y);
    }

    bool operator!= (const point& other) const
    {
        return !(*this == other);
    }

    point operator+ (const point& other) const
    {
        return point(x + other.x, y + other.y);
    }

    point operator- (const point& other) const
    {
        return point(x - other.x, y - other.y);
    }

    point operator/ (const double d) const
    {
        return point (x / d, y / d);
    }

    double operator* (const point& other) const
    {
        return x * other.y - y * other.x;
    }

    point operator* (const double d) const
    {
        return point (x * d, y * d);
    }

    double operator% (const point& other) const
    {
        return x * other.x + y * other.y;
    }

    double length() const
    {
        return sqrt(sqr(x) + sqr(y));
    }

    point normalize (double k = 1) const
    {
        double len = length();
        return *this * (k / len);
    }

    double distTo(const point& other) const
    {
        return (*this - other).length();
    }

    bool onLine (const point& a, const point& b) const
    {
        return doubleEqual((a - *this) * (b - *this), 0);
    }


    bool inSegment (const point& a, const point& b) const
    {
        return onLine (a, b) && doubleLessOrEqual ((a - *this) % (b - *this), 0);
    }

    point getH (const point& a, const point& b)
    {
        point c = *this;
        point v = b - a;
        point u = c - a;
        double k = v % u / v.length();
        //cerr << "k = " << k << endl;
        v = v.normalize(k);
        //cerr << "v = " << v.x << ", " << v.y << endl;
        return a + v;
    }
};

point intersect(const point& a, const point& b, const point& c, const point& d)
{
    point v = b - a;
    double s1 = (c - a) * (d - a);
    double s2 = (d - b) * (c - b);
    double s = s1 + s2;
    v = v / s;
    v = v * s1;
    return a + v;
}

istream& operator>> (istream& in, point& p)
{
    in >> p.x >> p.y;
    return in;
}

ostream& operator<< (ostream& out, const point& p)
{
    out << p.x << ", " << p.y;
    return out;
}

double rect_triangle_area (const point& h1, const point& h2, const point& r)
{
    double c1 = r.distTo(h1);
    double c2 = r.distTo(h2);
    return c1 * c2 / 2;
}

int main()
{
    point a (0, 0);
    point b (10, 0);
    point c (10, 10);

    point p = a;
    point f;

    cin >> f;

    if (doubleLessOrEqual(f * (c - a), 0))
    {
        cout << "0.0000" << endl;
        return 0;
    }

    double S = rect_triangle_area(a, c, b);
    double area = 0;
    while (S >= epsilon)
    {
        //cerr << "a = " << a << endl;
        //cerr << "b = " << b << endl;
        //cerr << "c = " << c << endl;

        point h = b.getH (a, c);
        //cerr << "h = " << h << endl;

        double x1 = rect_triangle_area (a, b, h);
        double x2 = rect_triangle_area (b, c, h);

        if (f.inSegment (b, h))
        {
            assert(f != b && f != h);
            if (((h - b) * (p - b)) * ((h - b) * (a - b)) > 0)
            {
                bool ok = true;
                if (f == b && !doubleLess(((a - b)*(p - b))*((h - b)*(p - b)), 0))
                    ok = false;
                else if (f == h && !doubleLess(((a - h)*(p - h))*((b - h)*(p - h)), 0))
                    ok = false;
                if (ok)
                    area += x1;
            }
            else
            {
                bool ok = true;
                if (f == b && !doubleLess(((c - b)*(p - b))*((h - b)*(p - b)), 0))
                    ok = false;
                else if (f == h && !doubleLess(((c - h)*(p - h))*((b - h)*(p - h)), 0))
                    ok = false;
                if (ok)
                    area += x2;
            }

            break;
        }

        //cerr << "x1 = " << x1 << ", x2 = " << x2 << endl;

        point i = intersect (p, f, b, h);
        //cerr << "i = " << i << endl;
        bool add = i.inSegment(p, f) && i != b && i != h;
        if (((b - h) * (b - f)) * ((b - f) * (b - c)) > 0)
        {
            if (add)
            {
                area += x1;
                //cerr << "area += " << x1 << endl;
            }
            S = x2;
            a = b;
            b = h;
        }
        else
        {
            if (add)
            {
                area += x2;
                //cerr << "area += " << x2 << endl;
            }
            S = x1;
            c = b;
            b = h;
        }

    }
    printf("%.7f\n", area);
//    cout << area << endl;

    return 0;
}
