#include <iostream>
#include <cmath>
#include <vector>
#include <cstdio>
#include <cstdlib>
#include <iomanip>
using namespace std;

const double eps = 1e-9;

template<typename T>
inline T sqr(T x)
{
    return x * x;
}

struct IntPoint
{
    long long x, y, z;

    IntPoint() :
        x(0),
        y(0),
        z(0)
    {
    }

    IntPoint(long long x, long long y, long long z) :
        x(x),
        y(y),
        z(z)
    {
    }

};

istream& operator >> (istream& input_stream, IntPoint& point)
{
    input_stream >> point.x >> point.y >> point.z;
    return input_stream;
}

IntPoint operator - (const IntPoint& lhs, const IntPoint& rhs)
{
    return IntPoint(lhs.x - rhs.x, lhs.y - rhs.y, lhs.z - rhs.z);
}

IntPoint operator + (const IntPoint& lhs, const IntPoint& rhs)
{
    return IntPoint(lhs.x + rhs.x, lhs.y + rhs.y, lhs.z + rhs.z);
}

IntPoint IntVMult(const IntPoint& lhs, const IntPoint& rhs)
{
    return IntPoint(lhs.y * rhs.z - lhs.z * rhs.y,
                  -(lhs.x * rhs.z - rhs.x * lhs.z),
                 lhs.x * rhs.y - rhs.x * lhs.y);
}

IntPoint operator * (long long d, const IntPoint& point)
{
    return IntPoint(d * point.x, d * point.y, d * point.z);
}

long long IntSMult(const IntPoint& lhs, const IntPoint& rhs)
{
    return lhs.x * rhs.x + lhs.y * rhs.y + lhs.z * rhs.z;
}

struct Point
{
    double x, y, z;

    Point() :
        x(0.0),
        y(0.0),
        z(0.0)
    {
    }

    Point(double x, double y, double z) :
        x(x),
        y(y),
        z(z)
    {
    }

    explicit Point(const IntPoint& point) :
        x(point.x),
        y(point.y),
        z(point.z)
    {
    }
};

double Length(const Point& point)
{
    return sqrt(sqr(point.x) + sqr(point.y) + sqr(point.z));
}

istream& operator >> (istream& input_stream, Point& point)
{
    input_stream >> point.x >> point.y >> point.z;
    return input_stream;
}

ostream& operator << (ostream& output_stream, const Point& point)
{
    output_stream << "(" << point.x << ", " << point.y << ", " << point.z << ")";
    return output_stream;
}

Point operator - (const Point& lhs, const Point& rhs)
{
    return Point(lhs.x - rhs.x, lhs.y - rhs.y, lhs.z - rhs.z);
}

Point operator / (const Point& point, double d)
{
    return Point(point.x / d, point.y / d, point.z / d);
}

Point operator + (const Point& lhs, const Point& rhs)
{
    return Point(lhs.x + rhs.x, lhs.y + rhs.y, lhs.z + rhs.z);
}

Point VMult(const Point& lhs, const Point& rhs)
{
    return Point(lhs.y * rhs.z - lhs.z * rhs.y,
                  -(lhs.x * rhs.z - rhs.x * lhs.z),
                 lhs.x * rhs.y - rhs.x * lhs.y);
}

Point operator * (double d, const Point& point)
{
    return Point(d * point.x, d * point.y, d * point.z);
}

double SMult(const Point& lhs, const Point& rhs)
{
    return lhs.x * rhs.x + lhs.y * rhs.y + lhs.z * rhs.z;
}

double GetDoubledTriangleSquare(const Point& A, const Point& B, const Point& C)
{
    return Length(VMult(C - A, C - B));
}

double GetDistToPlane(const Point& A, const Point& B, const Point& C,
                    const Point& P)
{
    double V = SMult(VMult(P - A, P - B), P - C);

    double S = GetDoubledTriangleSquare(A, B, C);

    return fabs(V / S);
}

void GetIntPlaneEquation(const IntPoint& P1, const IntPoint& P2, const IntPoint& P3,
                         long long& A, long long& B, long long& C, long long& D)
{
    IntPoint n = IntVMult(P2 - P1, P3 - P1);

    A = n.x;
    B = n.y;
    C = n.z;

    D = -(A * P1.x + B * P1.y + C * P1.z);
}

struct Edge
{
    IntPoint A;
    IntPoint B;
    IntPoint C;

    Edge(const IntPoint& A, const IntPoint& B, const IntPoint& C) :
        A(A),
        B(B),
        C(C)
    {
    }
};

struct PolyHedra
{
    vector<IntPoint> points;

    vector<Edge> edges;
};


bool IsGoodPlane(const PolyHedra& ph, const IntPoint& P1, const IntPoint& P2, const IntPoint& P3)
{
    long long A, B, C, D;

    GetIntPlaneEquation(P1, P2, P3, A, B, C, D);

    int ls;
    int mr;

    ls = mr = 0;

    int size = ph.points.size();
    for (int i = 0; i < size; ++i) {
        long long val = ph.points[i].x * A + ph.points[i].y * B +
                    ph.points[i].z * C + D;

        if (val == 0) {
            ++ls;
            ++mr;
        } else if (val > 0) {
            ++mr;
        } else {
            ++ls;
        }
    }

    return mr == size || ls == size;
}

void ConstructEdges(PolyHedra& ph)
{
    ph.edges.clear();

    int size = ph.points.size();
    for (int i = 0; i < size; ++i) {
        for (int j = i + 1; j < size; ++j) {
            for (int k = j + 1; k < size; ++k) {
                if (IsGoodPlane(ph, ph.points[i], ph.points[j], ph.points[k])) {
                    ph.edges.push_back(Edge(ph.points[i], ph.points[j], ph.points[k]));
                }
            }
        }
    }

}

istream& operator >> (istream& input_stream, PolyHedra& polyhedra)
{
    int size;
    input_stream >> size;
    polyhedra.points.resize(size);

    for (int i = 0; i < size; ++i) {
        input_stream >> polyhedra.points[i];
    }

    ConstructEdges(polyhedra);


    return input_stream;
}

Point GetCenterOfMassOfPyramid(const Point& S, const Point& A, const Point& B, const Point& C)
{
    Point result = S + A + B + C;

    result = result / 4.0;

    return result;
}

double GetVolumeOfPyramid(const Point& S, const Point& A, const Point& B, const Point& C)
{
    return fabs(SMult(VMult(A - S, B - S), C - S));
}

Point GetCenterOfMass(const PolyHedra& polyhedra)
{
    Point result;

    double V = 0.0;

    int size = polyhedra.edges.size();
    for (int i = 0; i < size; ++i) {
        double cur_V = GetVolumeOfPyramid(Point(polyhedra.points[0]), Point(polyhedra.edges[i].A),
                                                                Point(polyhedra.edges[i].B),
                                                                Point(polyhedra.edges[i].C));

        Point p = GetCenterOfMassOfPyramid(Point(polyhedra.points[0]), Point(polyhedra.edges[i].A),
                                                                Point(polyhedra.edges[i].B),
                                                                Point(polyhedra.edges[i].C));

        result = result + cur_V * p;

        V += cur_V;
    }

    result = result / V;

    return result;
}

double GetDistFromPointToPolyHedra(const Point& p,
                                    const PolyHedra& ph)
{
    double dist;
    bool found = false;

    int size = ph.edges.size();
    for (int i = 0; i < size; ++i) {
        double cur_dist = GetDistToPlane(Point(ph.edges[i].A), Point(ph.edges[i].B), Point(ph.edges[i].C), p);

        if (!found || cur_dist < dist) {
            found = true;
            dist = cur_dist;
        }
    }

    return dist;
}

int main()
{
    ios_base::sync_with_stdio(false);

    PolyHedra ph1, ph2;

    cin >> ph1 >> ph2;

    Point c1, c2;

    c1 = GetCenterOfMass(ph1);
    c2 = GetCenterOfMass(ph2);

    double dist1 = GetDistFromPointToPolyHedra(c1, ph1);
    double dist2 = GetDistFromPointToPolyHedra(c2, ph2);

    cout << fixed << setprecision(15);

    cout << dist1 + dist2 << endl;

    return 0;
}
