#include <iostream>
#include <algorithm>
#include <string>
#include <vector>
#include <set>
#include <map>
#include <queue>
#include <bitset>
#include <sstream>
#include <cstdio>
#include <cstring>
#include <cmath>
#include <climits>
#include <cctype>
#include <cstdlib>
using namespace std;

#define FOR(i,a,b) for(int i=(a);i<(b);i++)
#define ROF(i,a,b) for(int i=(b)-1;i>=(a);i--)

typedef long long LL;
typedef LL ll;
typedef pair<int, int> pii;
const int INF = 1000000000;
const LL LINF = 1000000000000000000LL;
const double PI = 3.1415926535897932384626433832795;

struct Vector2D {
  double x, y;

  Vector2D(double x = 0.0, double y = 0.0) : x(x), y(y) {}
};

Vector2D operator+(const Vector2D& u, const Vector2D& v) {
  return Vector2D(u.x + v.x, u.y + v.y);
}

Vector2D operator-(const Vector2D& u, const Vector2D& v) {
  return Vector2D(u.x - v.x, u.y - v.y);
}

double dot(const Vector2D& u, const Vector2D& v) {
  return u.x * v.x + u.y * v.y;
}

double cross(const Vector2D& u, const Vector2D& v) {
  return u.x * v.y - u.y * v.x;
}

Vector2D operator*(double k, const Vector2D& u) {
  return Vector2D(k * u.x, k * u.y);
}
Vector2D operator*(const Vector2D& u, double k) {
  return Vector2D(k * u.x, k * u.y);
}
typedef Vector2D Point2D;

struct Vector {
  double x, y, z;

  Vector(double x = 0.0, double y = 0.0, double z = 0.0) : x(x), y(y), z(z) {}
};

Vector operator+(const Vector& u, const Vector& v) {
  return Vector(u.x + v.x, u.y + v.y, u.z + v.z);
}

Vector operator-(const Vector& u, const Vector& v) {
  return Vector(u.x - v.x, u.y - v.y, u.z - v.z);
}

double dot(const Vector& u, const Vector& v) {
  return u.x * v.x + u.y * v.y + u.z * v.z;
}
Vector cross(Vector const& a, Vector const& b) {
  return Vector(a.y * b.z - a.z * b.y,
                a.z * b.x - a.x * b.z,
                a.x * b.y - a.y * b.x);
}
double length(Vector const& a) {
  return sqrt(dot(a, a));
}

Vector operator - (Vector const& a) {
  return Vector(-a.x, -a.y, -a.z);
}

Vector operator*(double k, const Vector& u) {
  return Vector(k * u.x, k * u.y, k * u.z);
}
Vector operator*(const Vector& u, double k) {
  return Vector(k * u.x, k * u.y, k * u.z);
}

typedef Vector Point;

struct Plane {
  Vector normal;
  double dist;
  Plane() {}
  Plane(Vector const& v, double d) : normal(v), dist(d) {
    double x = 1 / length(normal);
    normal = normal * x;
    dist *= x;
  }
};
vector<Plane> hull;
vector<Point> points;
bool v3equal(Plane const& a, Plane const& b) {
  return (fabs(a.normal.x - b.normal.x) < 1e-8) &&
         (fabs(a.normal.y - b.normal.y) < 1e-8) &&
         (fabs(a.normal.z - b.normal.z) < 1e-8);
}
bool v3less(Plane const& a, Plane const& b) {
  if (fabs(a.normal.x - b.normal.x) > 1e-8) return a.normal.x < b.normal.x;
  if (fabs(a.normal.y - b.normal.y) > 1e-8) return a.normal.y < b.normal.y;
  if (fabs(a.normal.z - b.normal.z) > 1e-8) return a.normal.z < b.normal.z;
  return a.dist < b.dist;
}
void HullAdd(Vector n, double d) {
  for (int i = 0; i < points.size(); i++) {
    if (dot(points[i], n) + d > 1e-8) {
      return;
    }
  }
  hull.push_back(Plane(n, d));
}

void BuildHull() {
  for (int i = 0; i < points.size(); i++) {
    for (int j = i + 1; j < points.size(); j++) {
      int k = 0;
      Point a = points[i];
      Point b = points[j];
      while (k == i || k == j) k++;
      Point left = points[k], right = points[k];
      Vector nleft = cross(left - a, b - a), nright = cross(right - b, a - b);
      double dleft = dot(nleft, a), dright = dot(nright, b);
      for (k++; k < points.size(); k++) {
        if (k == i || k == j) continue;
        if (dot(points[k], nleft) > dleft) {
          left = points[k];
          nleft = cross(left - a, b - a);
          dleft = dot(nleft, a);
        }
        if (dot(points[k], nright) > dright) {
          right = points[k];
          nright = cross(right - b, a - b);
          dright = dot(nright, b);
        }
      }
      HullAdd(nleft, -dleft);
      HullAdd(nright, -dright);
    }
  }
}

struct Line {
  Vector2D n;
  double d;
  double angle;
  Line() {}
  Line(Vector2D const& v, double gd) : n(v), d(gd) {
    angle = atan2(n.y, n.x);
    if (angle < -PI / 2 - 1e-8) angle += 2 * PI;
  }
};
Point2D intersect(Line const& a, Line const& b) {
  double den = cross(a.n, b.n);
  return Vector2D(
    (-a.d * b.n.y + b.d * a.n.y) / den,
    (-a.n.x * b.d + b.n.x * a.d) / den
  );
}

bool operator < (Point2D const& a, Point2D const& b) {
  return a.x < b.x - 1e-8 || (fabs(a.x - b.x) <= 1e-8 && a.y < b.y - 1e-8);
}
bool operator == (Point2D const& a, Point2D const& b) {
  return fabs(a.x - b.x) <= 1e-8 && fabs(a.y - b.y) <= 1e-8;
}

bool comparator(Line const& a, Line const& b) {
  if (fabs(a.angle - b.angle) < 1e-8) return a.d > b.d;
  return a.angle < b.angle;
}
bool lequal(Line const& a, Line const& b) {
  return fabs(a.angle - b.angle) < 1e-8;
}
double GetArea(double z) {
  vector<Line> lines;
  for (int i = 0; i < hull.size(); i++) {
    if (hull[i].normal.x * hull[i].normal.x + hull[i].normal.y * hull[i].normal.y < 1e-8) continue;
    lines.push_back(Line(Vector2D(hull[i].normal.x, hull[i].normal.y), hull[i].normal.z * z + hull[i].dist));
  }
  sort(lines.begin(), lines.end(), comparator);
  lines.resize(unique(lines.begin(), lines.end(), lequal) - lines.begin());

  vector<Point2D> poly;
  vector<Line> linelist;
  for (int s = 0; s < 2; s++) {
    for (int i = 0; i < lines.size(); i++) {
      while (poly.size() && dot(poly.back(), lines[i].n) + lines[i].d > -1e-8) {
        poly.pop_back();
        linelist.pop_back();
      }
      if (linelist.size()) {
        poly.push_back(intersect(lines[i], linelist.back()));
      }
      linelist.push_back(lines[i]);
    }
  }
  map<Point2D, int> pset;
  int first = -1;
  int last = -1;
  for (int i = 0; i < poly.size(); i++) {
    if (pset.find(poly[i]) != pset.end()) {
      first = pset[poly[i]];
      last = i;
    }
    pset[poly[i]] = i;
  }
  double answer = 0;
  for (int i = first + 2; i < last; i++) {
    answer += fabs(cross(poly[i] - poly[first], poly[i - 1] - poly[first])) * 0.5;
  }
  return answer;
}

int main() {
  int n, z0, z1;
  cin >> n >> z0 >> z1;
  double zmin = 1e+9, zmax = 1e-9;
  FOR(i, 0, n) {
    double x, y, z;
    cin >> x >> y >> z;
    points.push_back(Vector(x, y, z));
    zmin = min(zmin, z);
    zmax = max(zmax, z);
  }
  BuildHull();
  sort(hull.begin(), hull.end(), v3less);
  hull.resize(unique(hull.begin(), hull.end(), v3equal) - hull.begin());
  cout.precision(9);
  for (int z = z0; z <= z1; z++) {
    if (z < zmin - 1e-8 || z > zmax + 1e-8) {
      cout << "0\n";
    } else {
      cout << fixed << GetArea(z) << "\n";
    }
  }
  return 0;
}
